Module: Roda::RodaPlugins::MultiRoute::RequestClassMethods

Defined in:
lib/roda/plugins/multi_route.rb

Instance Method Summary collapse

Instance Method Details

#clear_named_route_regexp!Object

Clear cached regexp for named routes, it will be regenerated the next time it is needed.

This shouldn’t be an issue in production applications, but during development it’s useful to support new named routes being added while the application is running.



97
98
99
# File 'lib/roda/plugins/multi_route.rb', line 97

def clear_named_route_regexp!
  @named_route_regexp = nil
end

#named_route_regexpObject

A regexp matching any of the current named routes.



102
103
104
# File 'lib/roda/plugins/multi_route.rb', line 102

def named_route_regexp
  @named_route_regexp ||= /(#{Regexp.union(roda_class.named_routes.select{|s| s.is_a?(String)})})/
end